==> billogram-foundation-4.6.4.tgz: package/modules/components/radio/option-default/RadioButtonOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../../utils/isNullOrEmpty';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            checked: PropTypes.bool,
            disabled: PropTypes.bool,
            onChange: PropTypes.func,
            text: PropTypes.node,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                checked: false,
                disabled: false,
                onChange: () => {},
                text: '',
                value: ''
            };
        },

        onClick() {
            const { checked, disabled, onChange, value } = this.props;
            if (checked || disabled) {
                return;
            }

            onChange(value);
        },

        render() {
            const { checked, disabled, text } = this.props;
            return (
                <div
                    className={ block('option-default', { disabled, checked, unchecked: !checked }) }
                    onClick={ this.onClick }>
                    <i className={ block('option-default-symbol') } />
                    <span className={ block('option-default-content') }>{ text }</span>
                </div>
            );
        }

    });

};

==> billogram-foundation-4.8.4.tgz: package/modules/components/radio/option-default/RadioButtonOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../../utils/isNullOrEmpty';


export default ({
    block,
    displayName,
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            checked: PropTypes.bool,
            disabled: PropTypes.bool,
            onChange: PropTypes.func,
            text: PropTypes.node,
            value: PropTypes.string,
        },

        getDefaultProps() {
            return {
                checked: false,
                disabled: false,
                onChange: () => {},
                text: '',
                value: '',
            };
        },

        onClick() {
            const { checked, disabled, onChange, value } = this.props;
            if (checked || disabled) {
                return;
            }

            onChange(value);
        },

        render() {
            const { checked, disabled, text } = this.props;
            return (
                <div
                    className={ block('option-default', { disabled, checked, unchecked: !checked }) }
                    onClick={ this.onClick }>
                    <i className={ block('option-default-symbol') } />
                    <span className={ block('option-default-content') }>{ text }</span>
                </div>
            );
        },

    });

};
